# booq

Python implementation of of booq - a tool calculating binary year to date metrics with monthly cumulative slices. 

[License: MIT](https://git.sr.ht/~sthagen/booq/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/booq.svg?style=flat)](https://pypi.python.org/pypi/booq/)
[![downloads](https://pepy.tech/badge/booq/month)](https://pepy.tech/project/booq)
[![wheel](https://img.shields.io/pypi/wheel/booq.svg?style=flat)](https://pypi.python.org/pypi/booq/)
[![supported-versions](https://img.shields.io/pypi/pyversions/booq.svg?style=flat)](https://pypi.python.org/pypi/booq/)
[![supported-implementations](https://img.shields.io/pypi/implementation/booq.svg?style=flat)](https://pypi.python.org/pypi/booq/)

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of booq](https://todo.sr.ht/~sthagen/booq).

## Primary Source repository

The primary source repository of [booq is at sourcehut](https://git.sr.ht/~sthagen/booq)
a collection of tools useful for software development.
